Type: Package
Package: DT
Title: A Wrapper of the JavaScript Library 'DataTables'
Version: 0.34.0
Authors@R: c(
    person("Yihui", "Xie", role = "aut"),
    person("Joe", "Cheng", , "joe@posit.co", role = "aut"),
    person("Xianying", "Tan", role = "aut"),
    person("Garrick", "Aden-Buie", , "garrick@posit.co", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-7111-0077")),
    person("JJ", "Allaire", role = "ctb"),
    person("Maximilian", "Girlich", role = "ctb"),
    person("Greg", "Freedman Ellis", role = "ctb"),
    person("Johannes", "Rauh", role = "ctb"),
    person("SpryMedia Limited", role = c("ctb", "cph"),
           comment = "DataTables in htmlwidgets/lib"),
    person("Brian", "Reavis", role = c("ctb", "cph"),
           comment = "selectize.js in htmlwidgets/lib"),
    person("Leon", "Gersen", role = c("ctb", "cph"),
           comment = "noUiSlider in htmlwidgets/lib"),
    person("Bartek", "Szopka", role = c("ctb", "cph"),
           comment = "jquery.highlight.js in htmlwidgets/lib"),
    person("Alex", "Pickering", role = "ctb"),
    person("William", "Holmes", role = "ctb"),
    person("Mikko", "Marttila", role = "ctb"),
    person("Andres", "Quintero", role = "ctb"),
    person("Stéphane", "Laurent", role = "ctb"),
    person("Posit Software, PBC", role = c("cph", "fnd"))
  )
Description: Data objects in R can be rendered as HTML tables using the
    JavaScript library 'DataTables' (typically via R Markdown or Shiny).
    The 'DataTables' library has been included in this R package. The
    package name 'DT' is an abbreviation of 'DataTables'.
License: MIT + file LICENSE
URL: https://github.com/rstudio/DT
BugReports: https://github.com/rstudio/DT/issues
Imports: crosstalk, htmltools (>= 0.3.6), htmlwidgets (>= 1.3),
        jquerylib, jsonlite (>= 0.9.16), magrittr, promises
Suggests: bslib, future, httpuv, knitr (>= 1.8), rmarkdown, shiny (>=
        1.6), testit, tibble
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-09-02 13:12:27 UTC; garrick
Author: Yihui Xie [aut],
  Joe Cheng [aut],
  Xianying Tan [aut],
  Garrick Aden-Buie [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7111-0077>),
  JJ Allaire [ctb],
  Maximilian Girlich [ctb],
  Greg Freedman Ellis [ctb],
  Johannes Rauh [ctb],
  SpryMedia Limited [ctb, cph] (DataTables in htmlwidgets/lib),
  Brian Reavis [ctb, cph] (selectize.js in htmlwidgets/lib),
  Leon Gersen [ctb, cph] (noUiSlider in htmlwidgets/lib),
  Bartek Szopka [ctb, cph] (jquery.highlight.js in htmlwidgets/lib),
  Alex Pickering [ctb],
  William Holmes [ctb],
  Mikko Marttila [ctb],
  Andres Quintero [ctb],
  Stéphane Laurent [ctb],
  Posit Software, PBC [cph, fnd]
Maintainer: Garrick Aden-Buie <garrick@posit.co>
Repository: CRAN
Date/Publication: 2025-09-02 22:00:06 UTC
Built: R 4.6.0; ; 2026-04-29 09:30:45 UTC; unix
